.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    mer 09 lug 2014 10:11:06 CEST
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

======================================
 :mod:`sol.models.bio` -- Batched I/O
======================================

.. automodule:: sol.models.bio

.. autofunction:: save_changes

.. autofunction:: backup
.. autofunction:: restore

.. autofunction:: load_sol
.. autofunction:: dump_sol

.. autoclass:: Serializer
   :members:

.. autoclass:: Deserializer
   :members:
